==> ucsmsdk-0.9.0.0-py2.py3-none-any.whl: ucsmsdk/mometa/equipment/EquipmentPsuFsmStage.py <==
"""This module contains the general information for EquipmentPsuFsmStage ManagedObject."""
import sys, os

sys.path.append(os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))
from ucsmo import ManagedObject
from ucscoremeta import UcsVersion, MoPropertyMeta, MoMeta
from ucsmeta import VersionMeta
sys.path.remove(os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))


class EquipmentPsuFsmStageConsts():
    LAST_UPDATE_TIME_ = ""
    NAME_UPDATE_PSUACTIVATE_PSU = "UpdatePSUActivatePsu"
    NAME_UPDATE_PSUBEGIN = "UpdatePSUBegin"
    NAME_UPDATE_PSUFAIL = "UpdatePSUFail"
    NAME_UPDATE_PSUPOLL_ACTIVATE_STATUS = "UpdatePSUPollActivateStatus"
    NAME_UPDATE_PSUPOLL_UPDATE_STATUS = "UpdatePSUPollUpdateStatus"
    NAME_UPDATE_PSUSUCCESS = "UpdatePSUSuccess"
    NAME_UPDATE_PSUUPDATE_REQUEST = "UpdatePSUUpdateRequest"
    NAME_NOP = "nop"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class EquipmentPsuFsmStage(ManagedObject):
    """This is EquipmentPsuFsmStage class."""

    consts = EquipmentPsuFsmStageConsts()
    naming_props = set([u'name'])

    mo_meta = MoMeta("EquipmentPsuFsmStage", "equipmentPsuFsmStage", "stage-[name]", VersionMeta.Version302c, "OutputOnly", 0xfL, [], [""], [u'equipmentPsuFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version302c, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, 0x2L, 0, 256, None, [], []), 
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version302c, MoPropertyMeta.NAMING, None, None, None, None, ["UpdatePSUActivatePsu", "UpdatePSUBegin", "UpdatePSUFail", "UpdatePSUPollActivateStatus", "UpdatePSUPollUpdateStatus", "UpdatePSUSuccess", "UpdatePSUUpdateRequest", "nop"], []), 
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, 0x4L, 0, 256, None, [], []), 
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []), 
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version302c, MoPropertyMeta.READ_WRITE, 0x8L, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.sacl = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "EquipmentPsuFsmStage", parent_mo_or_dn, **kwargs)

==> ucsmsdk-0.9.11-py2.py3-none-any.whl: ucsmsdk/mometa/equipment/EquipmentPsuFsmStage.py <==
"""This module contains the general information for EquipmentPsuFsmStage ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentPsuFsmStageConsts:
    LAST_UPDATE_TIME_ = ""
    NAME_UPDATE_PSUACTIVATE_PSU = "UpdatePSUActivatePsu"
    NAME_UPDATE_PSUBEGIN = "UpdatePSUBegin"
    NAME_UPDATE_PSUFAIL = "UpdatePSUFail"
    NAME_UPDATE_PSUPOLL_ACTIVATE_STATUS = "UpdatePSUPollActivateStatus"
    NAME_UPDATE_PSUPOLL_UPDATE_STATUS = "UpdatePSUPollUpdateStatus"
    NAME_UPDATE_PSUSUCCESS = "UpdatePSUSuccess"
    NAME_UPDATE_PSUUPDATE_REQUEST = "UpdatePSUUpdateRequest"
    NAME_NOP = "nop"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class EquipmentPsuFsmStage(ManagedObject):
    """This is EquipmentPsuFsmStage class."""

    consts = EquipmentPsuFsmStageConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("EquipmentPsuFsmStage", "equipmentPsuFsmStage", "stage-[name]", VersionMeta.Version302c, "OutputOnly", 0xf, [], [""], ['equipmentPsuFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version302c, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version302c, MoPropertyMeta.NAMING, None, None, None, None, ["UpdatePSUActivatePsu", "UpdatePSUBegin", "UpdatePSUFail", "UpdatePSUPollActivateStatus", "UpdatePSUPollUpdateStatus", "UpdatePSUSuccess", "UpdatePSUUpdateRequest", "nop"], []),
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version302c, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.sacl = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "EquipmentPsuFsmStage", parent_mo_or_dn, **kwargs)
